@@ -44,12 +44,12 @@
 *     License as published by the Free Software Foundation, either
 *     version 3 of the License, or (at your option) any later
 *     version.
-*     
+*
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
-*     
+*
 *     You should have received a copy of the GNU Lesser General
 *     License along with this program.  If not, see
 *     <http://www.gnu.org/licenses/>.
@@ -289,6 +289,12 @@ F77_INTEGER_FUNCTION(ast_frame)( INTEGER(NAXES),
    astWatchSTATUS(
       options = astString( OPTIONS, OPTIONS_length );
 
+/* Truncate the options string to exclude any trailing spaces. */
+      astChrTrunc( options );
+
+/* Truncate the options string to exlucde any trailing spaces. */
+      astChrTrunc( options );
+
 /* Change ',' to '\n' (see AST_SET in fobject.c for why). */
       if ( astOK ) {
          for ( i = 0; options[ i ]; i++ ) {
